@@ -28,12 +28,17 @@ class Beacon:
   # Check the services pulse using a ping
   def servicePulse(self):
     while True:
+      rmList = []
       for deviceID in self.devices.keys():
         if deviceID != self.project.id:
           response = self.callService(self.devices[deviceID], "/ping")
           if response is None:
             print("[Beacon] Device lost: ", self.devices[deviceID]["id"], self.devices[deviceID]["name"])
+            rmList.append(deviceID)
+      if len(rmList)>0:
+        for deviceID in rmList:
             del self.devices[deviceID]
+        rmList = []
       time.sleep(10)
 
   
